A function to reshape qtl's object of conditional genotype probabilities, and to calculate self QTL effects for all individuals with given deviation coefficients and conditional genotype probabilities.
genoprobs2selfprobs(genoprobs, a1, d1, contrasts = NULL)Conditional genotype probabilities as taken from qtl::calc.genoprob().
A numeric scalar indicating additive deviation.
A numeric scalar indicating dominance deviation.
A vector composed of three TRUE/FALSE values, which represents the presence/absence of specific genotypes as c(TRUE/FALSE, TRUE/FALSE, TRUE/FALSE) = AA, AB, BB.
A numeric matrix containing individuals x marker elements for self QTL effects.